@@ -23,7 +23,19 @@ from trading_backend.exchanges.binance import (
     Binance
 )
 
+from trading_backend.exchanges import okex
+from trading_backend.exchanges.okex import (
+    OKEx
+)
+
+from trading_backend.exchanges import ftx
+from trading_backend.exchanges.ftx import (
+    FTX
+)
+
 __all__ = [
     "Exchange",
     "Binance",
+    "OKEx",
+    "FTX",
 ]
