@@ -20,6 +20,7 @@ class Binance(exchanges.Exchange):
     SPOT_ID = "T9698EB7"
     MARGIN_ID = None
     FUTURE_ID = "uquVg2pc"
+    REF_ID = "135007948"
     IS_SPONSORING = True
 
     @classmethod
@@ -27,7 +28,7 @@ class Binance(exchanges.Exchange):
         return 'binance'
 
     def _get_order_custom_id(self):
-        return f"x-{self._get_id()}"
+        return f"x-{self._get_id()}{self._exchange.connector.client.uuid22()}"
 
     def get_orders_parameters(self, params=None) -> dict:
         params = super().get_orders_parameters(params)
@@ -42,9 +43,16 @@ class Binance(exchanges.Exchange):
                 })
             )
             if not details.get("rebateWorking", False):
-                return False, "This account has a referral code, which is incompatible"
+                ref_id = details.get("referrerId", None)
+                if ref_id is not None:
+                    return False, f"This account has a referral id equal to {ref_id} " \
+                                  f"which is incompatible ({self.REF_ID} as referral id or no referral id is required)"
+                return False, f"This account is incompatible, details: {details}. Please report this message to " \
+                              f"admins for investigation. " \
+                              f"An account with {self.REF_ID} as referral id or no referral id is required."
             if not details.get("ifNewUser", False):
-                return False, "This account is not new, which is incompatible"
+                return False, "Binance requires accounts that were created after july 1st 2021, " \
+                              "this account is too old."
         except AttributeError:
             return False, "Invalid request parameters"
         return True, None
